# This file has been generated


build_system = 'AppVeyor'
build_id = '32555898'
build_number = '657'
build_version = '1.0.657'
job_id = 'yv2aebaom0fsi2f4'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/pm/build/job/yv2aebaom0fsi2f4'
