# This file was automatically generated by sub\epyqlib\epyqlib\cli\generateversion.py
__version_build_time__ = '2020-04-30T12:46:41.168533'

__version__ = '2020.4.10'
__sha__ = '89b7d1391665eb4a9b3fae4bc59013d297206944'
__revision__ = '89b7d1391665eb4a9b3fae4bc59013d297206944'
